using System;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using GHI.Pins;

using Microtoolskit.Hardware.Sensors;
using Microtoolskit.Hardware.Displays;


namespace MiniSerreV1
{
    public class Program
    {
        public static void Main()
        {
            // Constantes 
            const float temperatureConsigne = 22;

            // Variables
            float temperature = 0;
            float ecart = 0.2f;
            bool ActiveAlarme = false;

            // Configuration des entres, sorties (Cration des objets)       
            OutputPort CdeChauffage = new OutputPort(FEZPandaIII.Gpio.D6, false); // CdeChauffage
            var Alarme = new PWM(FEZPandaIII.PwmOutput.D5, 2000, 0.5, false); // Alarme  crer
            ELCD162 Lcd = new ELCD162("COM1"); //Lcd  crer
            TMP102 ModuleMesureTemp = new TMP102();

            // Initialisations
            ModuleMesureTemp.Init(); // Rglage de l'adresse
            Lcd.Init(); Lcd.ClearScreen(); Lcd.CursorOff();
            temperature = ModuleMesureTemp.ReadAsCelcius(); // Lecture de la temprature
            Lcd.PutString("Temp=" + temperature.ToString("F1") + "degC");

            while (true)
            {
                temperature = ModuleMesureTemp.ReadAsCelcius(); // Lecture de la temprature

                Lcd.ClearScreen(); // Effacer l'cran
                Lcd.PutString("Temp=" + temperature.ToString("F1") + "degC"); // Afficher la temprature sur l'cran

                if (temperature >= temperatureConsigne + ecart)
                {
                    CdeChauffage.Write(false);
                    ActiveAlarme = true;
                }
                else if (temperature <= temperatureConsigne - ecart)
                    CdeChauffage.Write(true);

                if (ActiveAlarme == true)
                {
                    if ((temperature >= temperatureConsigne - 0.5) && (temperature <= temperatureConsigne + 0.5))
                        Alarme.Stop();
                    else
                        Alarme.Start();
                }

                Thread.Sleep(1000); // Attendre une seconde entre chaque mesure+
            }
        }
    }
}
